# New figures

library(tidyverse)
library(grid)
library(gridExtra)
library(scales)

fpath <- 'C:/Users/qdread/OneDrive - USDA/ars_projects/mengistu/project1_cropping_systems/revision/estimated_means'

letter_annotate <- function(L, vj = 1.3, hj = -0.5) annotate('text', x = -Inf, y = Inf, label = L, size = 4, vjust = vj, hjust = hj)

cols <- c('goldenrod', 'slateblue')

noxax <- theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())
noyax <- theme(axis.text.y = element_blank(), axis.title.y = element_blank())
noth <- theme(legend.position = 'none')

levels_pcrop <- c('c. soybean', 'soybean', 'cotton', 'corn')
levels_ccrop <- c('fallow', 'poultry litter', 'wheat', 'austrian winter pea', 'hairy vetch')

labels_p <- c('continuous\nsoybean', 'soybean', 'cotton', 'corn')
labels_c <- c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')

letter_size <- 6
line_thickness <- 0.7

orange_cols <- RColorBrewer::brewer.pal(9, 'Oranges')
hmlabs <- labs(x = 'Cover Crop', y = 'Previous Crop')

theme_set(theme_bw() + theme(
  strip.background = element_blank(),
  panel.grid = element_blank()
))

dat <- read_csv('yield_CFU_by_plot.csv', name_repair = 'universal', na = c('', ' ', '.')) %>%
  mutate(Previous.Crop = factor(tolower(Previous.Crop), levels = levels_pcrop),
         CoverCrop = factor(tolower(CoverCrop), levels = levels_ccrop),
         Rep = factor(Rep),
         Year = factor(Year))
dat_rawcfu <- read_csv('stem_soil_CFU_by_plant.csv', name_repair = 'universal', na = c('', ' ', '.')) %>%
  mutate(Previous.Crop = factor(tolower(Previous.Crop), levels = levels_pcrop),
         CoverCrop = factor(tolower(CoverCrop), levels = levels_ccrop),
         Plot = factor(Plot),
         Rep = factor(Rep),
         Year = factor(Year))

cld_pc <- read_csv(file.path(fpath, 'estimated_means_previouscrop.csv')) %>%
  mutate(Previous.Crop = factor(Previous.Crop, levels = levels_pcrop, labels = labels_p))
cld_cc <- read_csv(file.path(fpath, 'estimated_means_covercrop.csv')) %>%
  mutate(CoverCrop = factor(CoverCrop, levels = levels_ccrop, labels = labels_c))
cld_int <- read_csv(file.path(fpath, 'estimated_means_interaction.csv'))
cld_int2 <- read_csv(file.path(fpath, 'estimated_means_interaction2.csv'))

cld_int <- cld_int %>%
  left_join(cld_int2 %>% select(Variable, CoverCrop, Previous.Crop, Year, `Significance letter previous crop within cover crop`)) %>%
  mutate(Previous.Crop = factor(Previous.Crop, levels = levels_pcrop, labels = labels_p),
         CoverCrop = factor(CoverCrop, levels = levels_ccrop, labels = labels_c)) %>%
  rename(sig_row = `Significance letter cover crop within previous crop`, sig_col = `Significance letter previous crop within cover crop`)

cld_csoy_crop <- read_csv(file.path(fpath, 'estimated_means_continuoussoy_covercrop.csv'))
cld_csoy_year <- read_csv(file.path(fpath, 'estimated_means_continuoussoy_year.csv'))
cld_csoy_yearxtrt <- read_csv(file.path(fpath, 'estimated_means_continuoussoy_covercropxyear.csv')) %>%
  mutate(CoverCrop = factor(CoverCrop, levels = levels_ccrop, labels = labels_c))

plot_blups <- read_csv('C:/Users/qdread/OneDrive - USDA/ars_projects/mengistu/project1_cropping_systems/revision/plot_blups.csv')

# Figure 2 ----------------------------------------------------------------

# New version only showing marginal means for years combined
CLDplot_combined <- function(dat, xvar, yvar, show_letters = FALSE, x_name, y_name, y_trans, y_limits) {
  p <- ggplot(dat %>% filter(Variable == yvar & Year == 'both combined'), aes(y = response, ymin = lower.CL, ymax = upper.CL, x = {{xvar}})) +
    geom_errorbar(width = 0.1) +
    geom_point(size = 2) +
    scale_y_continuous(name = y_name, trans = y_trans, limits = y_limits, labels = comma) +
    scale_x_discrete(name = x_name)
  if (show_letters)
    p <- p + geom_text(aes(label = str_trim(`Significance letter`)), 
              position = position_nudge(x = 0.1), vjust = -0.5, hjust = 0)
  return(p)
}

p_stem_left <- CLDplot_combined(dat = cld_cc, xvar = CoverCrop, yvar = 'Tissue CFU', x_name = 'Cover Crop', y_name = 'Tissue CFU', y_trans = 'log10', y_limits = c(380, 12220))
p_stem_right <- CLDplot_combined(dat = cld_pc, xvar = Previous.Crop, yvar = 'Tissue CFU', x_name = 'Previous Crop', y_name = 'Tissue CFU', y_trans = 'log10', y_limits = c(380, 12220), show_letters = TRUE)

p_soil_left <- CLDplot_combined(dat = cld_cc, xvar = CoverCrop, yvar = 'Soil CFU', x_name = 'Cover Crop', y_name = 'Soil CFU', y_trans = 'log10', y_limits = c(26, 189))
p_soil_right <- CLDplot_combined(dat = cld_pc, xvar = Previous.Crop, yvar = 'Soil CFU', x_name = 'Previous Crop', y_name = 'Soil CFU', y_trans = 'log10', y_limits = c(26, 189))

p_yield_left <- CLDplot_combined(dat = cld_cc, xvar = CoverCrop, yvar = 'Yield', x_name = 'Cover Crop', y_name = parse(text = 'Yield~(kg~ha^-1)'), y_trans = 'identity', y_limits = c(1840, 3070))
p_yield_right <- CLDplot_combined(dat = cld_pc, xvar = Previous.Crop, yvar = 'Yield', x_name = 'Previous Crop', y_name = parse(text = 'Yield~(kg~ha^-1)'), y_trans = 'identity', y_limits = c(1840, 3070))

fig2 <- arrangeGrob(
  gtable_rbind(ggplotGrob(p_stem_left + noxax + letter_annotate('A')), 
               ggplotGrob(p_soil_left + noxax + letter_annotate('C')), 
               ggplotGrob(p_yield_left + letter_annotate('E'))),
  gtable_rbind(ggplotGrob(p_stem_right + noxax + noyax + letter_annotate('B')),
               ggplotGrob(p_soil_right + noxax + noyax + letter_annotate('D')), 
               ggplotGrob(p_yield_right + noyax + letter_annotate('F'))),
  nrow = 1, widths = c(1.3, 1)
)
ggsave('figs/fig2.png', fig2, height = 9, width = 7, dpi = 400)
ggsave('figs/fig2.eps', fig2, height = 9, width = 7)

# Figure 3 ----------------------------------------------------------------

# Modify significance label so that only those with at least one significant difference are shown
cld_int <- cld_int %>%
  group_by(Variable, Previous.Crop, Year) %>%
  mutate(label_row = if (length(unique(sig_row)) == 1) rep('', length(sig_row)) else sig_row) %>%
  ungroup %>%
  group_by(Variable, CoverCrop, Year) %>%
  mutate(label_col = if (length(unique(sig_col)) == 1) rep('', length(sig_col)) else sig_col) %>%
  ungroup

seg_dat_stem <- data.frame(x = c(3.5, 2.5), xend = c(4.5, 3.5), y = c(3.5, 1.5), yend = c(4.5, 2.5), Year = c(2011, 2015))
seg_dat_soil <- data.frame(x = c(3.5, 3.5, 4.5, 4.5), xend = c(4.5, 4.5, 5.5, 5.5), y = c(3.5, 1.5, 3.5, 1.5), yend = c(4.5, 2.5, 4.5, 2.5), Year = 2015)

off <- 0.2 # Offset of significance letters if there are more than one in a box

hm_stem_yr <- ggplot(cld_int %>% filter(Variable == 'Tissue CFU', Year %in% c('2011', '2015')), 
                     aes(x = CoverCrop, y = Previous.Crop)) +
  geom_tile(aes(fill = response)) +
  facet_wrap(~ Year, nrow = 2) +
  geom_text(aes(label = label_row), data = cld_int %>% filter(Variable == 'Tissue CFU', Year %in% c('2011', '2015'), label_col == '')) +
  geom_text(aes(label = label_col), data = cld_int %>% filter(Variable == 'Tissue CFU', Year %in% c('2011', '2015'), label_row == '')) +
  geom_text(aes(label = label_row), data = cld_int %>% filter(Variable == 'Tissue CFU', Year %in% c('2011', '2015'), label_col != ''), nudge_x = -off, nudge_y = off) +
  geom_text(aes(label = label_col), data = cld_int %>% filter(Variable == 'Tissue CFU', Year %in% c('2011', '2015'), label_row != ''), nudge_x = off, nudge_y = -off) +
  geom_segment(aes(x=x, y=y, xend=xend, yend=yend), data = seg_dat_stem) +
  scale_fill_gradientn(colours = orange_cols, name = 'Tissue CFU', labels = comma, limits = c(0, 12000), breaks = c(0, 6000, 12000)) +
  hmlabs +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.5)), legend.title = element_text(size = rel(0.8)), axis.title.y = element_text(size = rel(.8))) +
  geom_text(data = data.frame(CoverCrop = 'fallow', Previous.Crop = 'corn', Year = c(2011, 2015), letter = c('A', 'D')), aes(label = letter), size = 3.5, hjust = 1.7, vjust = -0.5)

hm_soil_yr <- ggplot(cld_int %>% filter(Variable == 'Soil CFU', Year %in% c('2011', '2015')), 
                     aes(x = CoverCrop, y = Previous.Crop)) +
  geom_tile(aes(fill = response)) +
  facet_wrap(~ Year, nrow = 2) +
  geom_text(aes(label = label_row), data = cld_int %>% filter(Variable == 'Soil CFU', Year %in% c('2011', '2015'), label_col == '')) +
  geom_text(aes(label = label_col), data = cld_int %>% filter(Variable == 'Soil CFU', Year %in% c('2011', '2015'), label_row == '')) +
  geom_text(aes(label = label_row), data = cld_int %>% filter(Variable == 'Soil CFU', Year %in% c('2011', '2015'), label_col != ''), nudge_x = -off, nudge_y = off) +
  geom_text(aes(label = label_col), data = cld_int %>% filter(Variable == 'Soil CFU', Year %in% c('2011', '2015'), label_row != ''), nudge_x = off, nudge_y = -off) +
  geom_segment(aes(x=x, y=y, xend=xend, yend=yend), data = seg_dat_soil) +
  scale_fill_gradientn(colours = orange_cols, name = 'Soil CFU', labels = comma) +
  hmlabs +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.5)), legend.title = element_text(size = rel(0.8))) +
  geom_text(data = data.frame(CoverCrop = 'fallow', Previous.Crop = 'corn', Year = c(2011, 2015), letter = c('B', 'E')), aes(label = letter), size = 3.5, hjust = 1.7, vjust = -0.5)

hm_yield_yr <- ggplot(cld_int %>% filter(Variable == 'Yield', Year %in% c('2011', '2015')), 
                      aes(x = CoverCrop, y = Previous.Crop)) +
  geom_tile(aes(fill = response)) +
  facet_wrap(~ Year, nrow = 2) +
  geom_text(aes(label = label_row)) +
  geom_text(aes(label = label_col)) +
  scale_fill_gradientn(colours = orange_cols, name = parse(text = 'Yield~(kg~ha^-1)'), labels = comma) +
  hmlabs +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.5)), legend.title = element_text(size = rel(0.8))) +
  geom_text(data = data.frame(CoverCrop = 'fallow', Previous.Crop = 'corn', Year = c(2011, 2015), letter = c('C', 'F')), aes(label = letter), size = 3.5, hjust = 1.7, vjust = -0.5)

noyax <- theme(axis.text.y = element_blank(), axis.title.y = element_blank())
smlabs1 <- theme(axis.text.x = element_text(size = rel(.7)), legend.key.width = unit(0.6, 'cm'), axis.text.y = element_text(size = rel(.7)), axis.title.x = element_text(size = rel(.8)))
smlabs2 <- theme(axis.text.x = element_text(size = rel(.7)), legend.key.width = unit(0.6, 'cm'), axis.title.x = element_text(size = rel(.8)))
fig3 <- arrangeGrob(hm_stem_yr + smlabs1, hm_soil_yr + noyax + smlabs2, hm_yield_yr + noyax + smlabs2, nrow = 1, widths = c(1.4, 1, 1))

ggsave('figs/fig3.png', fig3, height = 5, width = 7, dpi = 300)
ggsave('figs/fig3.eps', fig3, height = 5, width = 7)

# Pairs plot (fig 4) ------------------------------------------------------

library(GGally)

lab_exp <- c(logSoilCFU = 'log[10]~Soil~CFU', logStemCFU = 'log[10]~Tissue~CFU', YldKgHa = 'Yield~(kg~ha^-1)')

fig4 <- plot_blups %>%
  mutate(logSoilCFU = log10(exp(soilCFU)), logStemCFU = log10(exp(stemCFU))) %>%
  dplyr::select(logSoilCFU, logStemCFU, yield) %>%
  setNames(lab_exp) %>%
  ggpairs(labeller = label_parsed, switch = 'y', showStrips = FALSE) + theme(strip.placement = "outside")

ggsave('figs/fig4.png', fig4, height = 6, width = 7, dpi = 400)
ggsave('figs/fig4.eps', fig4, height = 6, width = 7)

# Fig 5 formatted ---------------------------------------------------------

# No title, tissue CFU instead of stem CFU, letters on panels, save as eps

ptrendmeans1 <- ggplot(cld_csoy_year %>% filter(Variable == 'Tissue CFU'), aes(x = Year, y = response)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop') +
  geom_errorbar(width = 0.1, linewidth = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(aes(x = as.numeric(Year))) +
  geom_point(data = cld_csoy_yearxtrt %>% filter(Variable == 'Tissue CFU'), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.17)) +
  geom_text(aes(y = upper.CL + 2000, label = `Significance letter`)) +
  labs(y = 'Tissue CFU') +
  #scale_x_discrete(expand = expansion(add = c(0.5, 0.1))) +
  theme(legend.position = c(0.65, 0.75), axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank(), 
        legend.background = element_rect(color = 'black', linewidth = 0.5), legend.text = element_text(size = rel(0.6)), legend.title = element_blank(),
        legend.margin = margin(0.05, 0.05, 0.05, 0.05)) +
  guides(color = guide_legend(ncol = 2)) 

ptrendmeans2 <- ggplot(cld_csoy_year %>% filter(Variable == 'Soil CFU'), aes(x = Year, y = response)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop') +
  geom_errorbar(width = 0.1, linewidth = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(aes(x = as.numeric(Year))) +
  geom_point(data = cld_csoy_yearxtrt %>% filter(Variable == 'Soil CFU'), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.17)) +
  geom_text(aes(y = upper.CL + 20, label = `Significance letter`)) +
  labs(y = 'Soil CFU') +
  #scale_x_discrete(expand = expansion(add = c(0.5, 0.1))) +
  theme(legend.position = 'none', axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())

ptrendmeans3 <- ggplot(cld_csoy_year %>% filter(Variable == 'Yield'), aes(x = Year, y = response)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop') +
  geom_errorbar(width = 0.1, linewidth = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(aes(x = as.numeric(Year))) +
  geom_point(data = cld_csoy_yearxtrt %>% filter(Variable == 'Yield'), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.17)) +
  geom_text(aes(y = upper.CL + 120, label = `Significance letter`)) +
  labs(y = parse(text = 'Yield~(kg~ha^-1)')) +
  #scale_x_discrete(expand = expansion(add = c(0.5, 0.1))) +
  theme(legend.position = 'none')

fig5 <- arrangeGrob(gtable_rbind(ggplotGrob(ptrendmeans1 + letter_annotate('A', hj = -0.3)), 
                                 ggplotGrob(ptrendmeans2 + letter_annotate('B', hj = -0.3)), 
                                 ggplotGrob(ptrendmeans3 + letter_annotate('C', hj = -0.3))))

ggsave('figs/fig5.png', fig5, height = 6, width = 3.25, dpi = 400)
ggsave('figs/fig5.eps', fig5, height = 6, width = 3.25)