# Two-panel main effect CLD plot figures
# QDR 09 November 2021

# Run notebook v2  through line 230

library(grid)
library(gridExtra)

cols <- c('goldenrod', 'slateblue')

noax <- theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())
noth <- theme(legend.position = 'none')

levels_p <- c('continuous\nsoybean', 'soybean', 'cotton', 'corn')
levels_c <- c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')

letter_size <- 6
line_thickness <- 0.7

orange_cols <- RColorBrewer::brewer.pal(9, 'Oranges')
hmlabs <- labs(x = 'Cover Crop', y = 'Previous Crop')

# Stem CFU
p_stem_left <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                           cld = cld_stem_c,
                           x_var = CoverCrop,
                           y_var = StemCFUAvg,
                           grp_var = factor(Year),
                           x_axis_label = 'Cover Crop',
                           y_axis_label = 'Stem CFU',
                           log_y = TRUE,
                           show_caption = FALSE,
                           mean_color = 'black',
                           plot_theme = theme_get() + theme(legend.position = 'none'),
                           points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Cover Crop', labels = c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

p_stem_right <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                            cld = cld_stem_p,
                            x_var = Previous.Crop,
                            y_var = StemCFUAvg,
                            grp_var = factor(Year),
                            x_axis_label = 'Previous Crop',
                            y_axis_label = 'Stem CFU',
                            log_y = TRUE,
                            show_caption = FALSE,
                            mean_color = 'black',
                            plot_theme = theme_get() + theme(axis.text.y = element_blank(),
                                                             axis.title.y = element_blank(),
                                                             legend.position = c(0.87, 0.11),
                                                             legend.title = element_text(size = rel(0.9)),
                                                             legend.text = element_text(size = rel(0.7))),
                            points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Previous Crop', labels = c('continuous\nsoybean', 'soybean', 'cotton', 'corn')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

# Soil CFU
p_soil_left <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                           cld = cld_soil_c,
                           x_var = CoverCrop,
                           y_var = SoilCFUAvg,
                           grp_var = factor(Year),
                           x_axis_label = 'Cover Crop',
                           y_axis_label = 'Soil CFU',
                           log_y = TRUE,
                           show_caption = FALSE,
                           mean_color = 'black',
                           plot_theme = theme_get() + theme(legend.position = 'none'),
                           points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Cover Crop', labels = c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

p_soil_right <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                            cld = cld_soil_p,
                            x_var = Previous.Crop,
                            y_var = SoilCFUAvg,
                            grp_var = factor(Year),
                            x_axis_label = 'Previous Crop',
                            y_axis_label = 'Soil CFU',
                            log_y = TRUE,
                            show_caption = FALSE,
                            mean_color = 'black',
                            plot_theme = theme_get() + theme(axis.text.y = element_blank(),
                                                             axis.title.y = element_blank(),
                                                             legend.position = c(0.87, 0.11),
                                                             legend.title = element_text(size = rel(0.9)),
                                                             legend.text = element_text(size = rel(0.7))),
                            points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Previous Crop', labels = c('continuous\nsoybean', 'soybean', 'cotton', 'corn')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

# Yield
p_yield_left <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                           cld = cld_yield_c,
                           x_var = CoverCrop,
                           y_var = YldKgHa,
                           grp_var = factor(Year),
                           x_axis_label = 'Cover Crop',
                           y_axis_label = parse(text = 'Yield~(kg~ha^-1)'),
                           log_y = FALSE,
                           show_caption = FALSE,
                           mean_color = 'black',
                           plot_theme = theme_get() + theme(legend.position = 'none'),
                           points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Cover Crop', labels = c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

p_yield_right <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                            cld = cld_yield_p,
                            x_var = Previous.Crop,
                            y_var = YldKgHa,
                            grp_var = factor(Year),
                            x_axis_label = 'Previous Crop',
                            y_axis_label = parse(text = 'Yield~(kg~ha^-1)'),
                            log_y = FALSE,
                            show_caption = FALSE,
                            mean_color = 'black',
                            plot_theme = theme_get() + theme(axis.text.y = element_blank(),
                                                             axis.title.y = element_blank(),
                                                             legend.position = c(0.87, 0.89),
                                                             legend.title = element_text(size = rel(0.9)),
                                                             legend.text = element_text(size = rel(0.7))),
                            points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Previous Crop', labels = c('continuous\nsoybean', 'soybean', 'cotton', 'corn')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

png('figs/stemcfu_maineffects.png', height = 4.5, width = 7.5, res = 300, units = 'in')
  grid.arrange(p_stem_left, p_stem_right, nrow = 1, widths = c(1.3, 1))
dev.off()

png('figs/soilcfu_maineffects.png', height = 4.5, width = 7.5, res = 300, units = 'in')
grid.arrange(p_soil_left, p_soil_right, nrow = 1, widths = c(1.3, 1))
dev.off()

png('figs/yield_maineffects.png', height = 4.5, width = 7.5, res = 300, units = 'in')
grid.arrange(p_yield_left, p_yield_right, nrow = 1, widths = c(1.3, 1))
dev.off()


# Simplified figures with no raw data -------------------------------------

# Stem CFU
p_stem_left <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                           cld = cld_stem_c,
                           x_var = CoverCrop,
                           y_var = StemCFUAvg,
                           grp_var = factor(Year),
                           x_axis_label = 'Cover Crop',
                           y_axis_label = 'Stem CFU',
                           log_y = TRUE,
                           show_caption = FALSE,
                           show_points = FALSE,
                           mean_color = 'black',
                           plot_theme = theme_get() + theme(legend.position = 'none'),
                           points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Cover Crop', labels = c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

p_stem_right <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                            cld = cld_stem_p,
                            x_var = Previous.Crop,
                            y_var = StemCFUAvg,
                            grp_var = factor(Year),
                            x_axis_label = 'Previous Crop',
                            y_axis_label = 'Stem CFU',
                            log_y = TRUE,
                            show_caption = FALSE,
                            show_points = FALSE,
                            mean_color = 'black',
                            plot_theme = theme_get() + theme(axis.text.y = element_blank(),
                                                             axis.title.y = element_blank(),
                                                             legend.position = c(0.87, 0.11),
                                                             legend.title = element_text(size = rel(0.9)),
                                                             legend.text = element_text(size = rel(0.7))),
                            points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Previous Crop', labels = c('continuous\nsoybean', 'soybean', 'cotton', 'corn')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

# Soil CFU
p_soil_left <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                           cld = cld_soil_c,
                           x_var = CoverCrop,
                           y_var = SoilCFUAvg,
                           grp_var = factor(Year),
                           x_axis_label = 'Cover Crop',
                           y_axis_label = 'Soil CFU',
                           log_y = TRUE,
                           show_caption = FALSE,
                           show_points = FALSE,
                           mean_color = 'black',
                           plot_theme = theme_get() + theme(legend.position = 'none'),
                           points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Cover Crop', labels = c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

p_soil_right <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                            cld = cld_soil_p,
                            x_var = Previous.Crop,
                            y_var = SoilCFUAvg,
                            grp_var = factor(Year),
                            x_axis_label = 'Previous Crop',
                            y_axis_label = 'Soil CFU',
                            log_y = TRUE,
                            show_caption = FALSE,
                            show_points = FALSE,
                            mean_color = 'black',
                            plot_theme = theme_get() + theme(axis.text.y = element_blank(),
                                                             axis.title.y = element_blank(),
                                                             legend.position = c(0.87, 0.11),
                                                             legend.title = element_text(size = rel(0.9)),
                                                             legend.text = element_text(size = rel(0.7))),
                            points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Previous Crop', labels = c('continuous\nsoybean', 'soybean', 'cotton', 'corn')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

# Yield
p_yield_left <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                            cld = cld_yield_c,
                            x_var = CoverCrop,
                            y_var = YldKgHa,
                            grp_var = factor(Year),
                            x_axis_label = 'Cover Crop',
                            y_axis_label = parse(text = 'Yield~(kg~ha^-1)'),
                            log_y = FALSE,
                            show_caption = FALSE,
                            show_points = FALSE,
                            mean_color = 'black',
                            plot_theme = theme_get() + theme(legend.position = 'none'),
                            points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Cover Crop', labels = c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

p_yield_right <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                             cld = cld_yield_p,
                             x_var = Previous.Crop,
                             y_var = YldKgHa,
                             grp_var = factor(Year),
                             x_axis_label = 'Previous Crop',
                             y_axis_label = parse(text = 'Yield~(kg~ha^-1)'),
                             log_y = FALSE,
                             show_caption = FALSE,
                             show_points = FALSE,
                             mean_color = 'black',
                             plot_theme = theme_get() + theme(axis.text.y = element_blank(),
                                                              axis.title.y = element_blank(),
                                                              legend.position = c(0.87, 0.89),
                                                              legend.title = element_text(size = rel(0.9)),
                                                              legend.text = element_text(size = rel(0.7))),
                             points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Previous Crop', labels = c('continuous\nsoybean', 'soybean', 'cotton', 'corn')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

png('figs/stemcfu_maineffects_norawdata.png', height = 4.5, width = 7.5, res = 300, units = 'in')
grid.arrange(p_stem_left, p_stem_right, nrow = 1, widths = c(1.3, 1))
dev.off()

png('figs/soilcfu_maineffects_norawdata.png', height = 4.5, width = 7.5, res = 300, units = 'in')
grid.arrange(p_soil_left, p_soil_right, nrow = 1, widths = c(1.3, 1))
dev.off()

png('figs/yield_maineffects_norawdata.png', height = 4.5, width = 7.5, res = 300, units = 'in')
grid.arrange(p_yield_left, p_yield_right, nrow = 1, widths = c(1.3, 1))
dev.off()

noax <- theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())
noth <- theme(legend.position = 'none')
png('figs/maineffects_norawdata.png', height = 9, width = 6.5, res = 300, units = 'in')
  grid.arrange(
    gtable_rbind(ggplotGrob(p_stem_left + noax), ggplotGrob(p_soil_left + noax), ggplotGrob(p_yield_left)),
    gtable_rbind(ggplotGrob(p_stem_right + noax + theme(legend.position = c(0.6, 0.1), legend.direction = 'horizontal')), ggplotGrob(p_soil_right + noax + noth), ggplotGrob(p_yield_right + noth)),
    nrow = 1, top = 'Marginal means for main effects', widths = c(1.3, 1)
  )
dev.off()


# Fig 2 formatted ---------------------------------------------------------

# No title, letters on panels, label should say tissue CFU, save as png and eps

p_stem_left <- CLDplot_lmm(dat = dat %>% filter(Year %in% c(2011, 2015)),
                           cld = cld_stem_c,
                           x_var = CoverCrop,
                           y_var = StemCFUAvg,
                           grp_var = factor(Year),
                           x_axis_label = 'Cover Crop',
                           y_axis_label = 'Tissue CFU',
                           log_y = TRUE,
                           show_caption = FALSE,
                           show_points = FALSE,
                           mean_color = 'black',
                           plot_theme = theme_get() + theme(legend.position = 'none'),
                           points_adj = 0.35, bp_adj = 0.2, bp_rel_width = 0.8) +
  scale_x_discrete(name = 'Cover Crop', labels = c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')) +
  scale_fill_manual(name = 'Year', values = cols) +
  scale_color_manual(name = 'Year', values = cols)

letter_annotate <- function(L) annotate('text', x = -Inf, y = Inf, label = L, size = 4, vjust = 1.1, hjust = -0.5)

fig2 <- arrangeGrob(
  gtable_rbind(ggplotGrob(p_stem_left + noax + letter_annotate('A')), 
               ggplotGrob(p_soil_left + noax + letter_annotate('C')), 
               ggplotGrob(p_yield_left + letter_annotate('E'))),
  gtable_rbind(ggplotGrob(p_stem_right + noax + theme(legend.position = c(0.6, 0.1), legend.direction = 'horizontal', legend.background = element_blank()) + letter_annotate('B')),
               ggplotGrob(p_soil_right + noax + noth + letter_annotate('D')), 
               ggplotGrob(p_yield_right + noth + letter_annotate('F'))),
  nrow = 1, widths = c(1.3, 1)
)
ggsave('figs/fig2.png', fig2, height = 9, width = 7, dpi = 400)
ggsave('figs/fig2.eps', fig2, height = 9, width = 7)

# Even more simplified with no year variation -----------------------------

# bar chart
# ggplot(cld_yield_c, aes(x = CoverCrop, y = emmean, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
#   geom_col() +
#   geom_errorbar(width = 0.2, size = 1) +
#   geom_text(aes(y = upper.CL), position = position_nudge(y = 0.1)) +
#   scale_x_discrete(labels = c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch'),
#                    name = 'cover crop') +
#   scale_y_continuous(name = parse(text = 'Yield~(kg~ha^-1)'), expand = expansion(mult = c(0, 0.02)))

levels_p <- c('continuous\nsoybean', 'soybean', 'cotton', 'corn')
levels_c <- c('fallow', 'poultry\nlitter', 'wheat', 'Austrian\nwinter pea', 'hairy\nvetch')

max_yield <- max(c(cld_yield_c$upper.CL, cld_yield_p$upper.CL))
range_stemcfu <- range(c(cld_stem_c$lower.CL, cld_stem_c$upper.CL, cld_stem_p$lower.CL, cld_stem_p$upper.CL))
range_soilcfu <- range(c(cld_soil_c$lower.CL, cld_soil_c$upper.CL, cld_soil_p$lower.CL, cld_soil_p$upper.CL))

letter_size <- 6
line_thickness <- 0.7

### yield
p_yield_left <- ggplot(cld_yield_c, aes(x = CoverCrop, y = emmean, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_c,
                   name = 'cover crop') +
  scale_y_continuous(name = parse(text = 'Yield~(kg~ha^-1)'),
                     limits = c(0, max_yield + 1),
                     expand = expansion(mult = c(0, 0.02)))

p_yield_right <- ggplot(cld_yield_p, aes(x = Previous.Crop, y = emmean, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_p,
                   name = 'previous crop') +
  scale_y_continuous(name = parse(text = 'Yield~(kg~ha^-1)'),
                     limits = c(0, max_yield + 1),
                     expand = expansion(mult = c(0, 0.02))) +
  theme(axis.text.y = element_blank(),
        axis.title.y = element_blank())

### stem cfu
p_stem_left <- ggplot(cld_stem_c, aes(x = CoverCrop, y = response, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_c,
                   name = 'cover crop') +
  scale_y_continuous(name = 'Stem CFU',
                     limits = c(0, range_stemcfu[2] + 1),
                     expand = expansion(mult = c(0, 0.02)))

p_stem_right <- ggplot(cld_stem_p, aes(x = Previous.Crop, y = response, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_p,
                   name = 'previous crop') +
  scale_y_continuous(name = 'Stem CFU',
                     limits = c(0, range_stemcfu[2] + 1),
                     expand = expansion(mult = c(0, 0.02))) +
  theme(axis.text.y = element_blank(),
        axis.title.y = element_blank())  

### soil cfu
p_soil_left <- ggplot(cld_soil_c, aes(x = CoverCrop, y = response, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_c,
                   name = 'cover crop') +
  scale_y_continuous(name = 'Soil CFU',
                     limits = c(0, range_soilcfu[2] + 1),
                     expand = expansion(mult = c(0, 0.02)))

p_soil_right <- ggplot(cld_soil_p, aes(x = Previous.Crop, y = response, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_p,
                   name = 'previous crop') +
  scale_y_continuous(name = 'Soil CFU',
                     limits = c(0, range_soilcfu[2] + 1),
                     expand = expansion(mult = c(0, 0.02))) +
  theme(axis.text.y = element_blank(),
        axis.title.y = element_blank())  

png('figs/stemcfu_maineffects_justmeans.png', height = 4.5, width = 7.5, res = 300, units = 'in')
grid.arrange(p_stem_left, p_stem_right, nrow = 1, widths = c(1.3, 1))
dev.off()

png('figs/soilcfu_maineffects_justmeans.png', height = 4.5, width = 7.5, res = 300, units = 'in')
grid.arrange(p_soil_left, p_soil_right, nrow = 1, widths = c(1.3, 1))
dev.off()

png('figs/yield_maineffects_justmeans.png', height = 4.5, width = 7.5, res = 300, units = 'in')
grid.arrange(p_yield_left, p_yield_right, nrow = 1, widths = c(1.3, 1))
dev.off()

# Combine into single fig.
noax <- theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())
png('figs/maineffects_justmeans.png', height = 9, width = 6.5, res = 300, units = 'in')
  grid.arrange(
    gtable_rbind(ggplotGrob(p_stem_left + noax), ggplotGrob(p_soil_left + noax), ggplotGrob(p_yield_left)),
    gtable_rbind(ggplotGrob(p_stem_right + noax), ggplotGrob(p_soil_right + noax), ggplotGrob(p_yield_right)),
    nrow = 1, top = 'Marginal means for main effects', widths = c(1.3, 1)
  )
dev.off()

# heat maps for each year separately --------------------------------------

# Display estimated marginal means

orange_cols <- RColorBrewer::brewer.pal(9, 'Oranges')
hmlabs <- labs(x = 'Cover Crop', y = 'Previous Crop')

emmeans_stem_yr <- emmeans(fit_stem, specs = ~ Previous.Crop + CoverCrop + Year, mode = 'kenward-roger', type = 'response')
#cld_stem_yr <- cld(emmeans_stem_yr, adjust = 'tukey', Letters = letters)

emmeans_soil_yr <- emmeans(fit_soil, specs = ~ Previous.Crop + CoverCrop + Year, mode = 'kenward-roger', type = 'response')
#cld_soil_yr <- cld(emmeans_soil_yr, adjust = 'tukey', Letters = letters)

emmeans_yield_yr <- emmeans(fit_yield, specs = ~ Previous.Crop + CoverCrop + Year, mode = 'kenward-roger', type = 'response')
#cld_yield_yr <- cld(emmeans_yield_yr, adjust = 'tukey', Letters = letters)

hm_stem_yr <- ggplot(emmeans_stem_yr %>% as_tibble, 
       aes(x = CoverCrop, y = Previous.Crop, fill = response)) +
  geom_tile() +
  facet_wrap(~ Year, nrow = 2) +
  #geom_text(aes(label = trimws(.group))) +
  scale_fill_gradientn(colours = orange_cols, name = 'Stem CFU', labels = comma, breaks = c(5000, 10000, 15000, 20000)) +
  hmlabs +
  scale_x_discrete(labels = levels_c) +
  scale_y_discrete(labels = levels_p) +
  ggtitle('Stem disease load') +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.6)), legend.title = element_text(size = rel(0.8)))

hm_soil_yr <- ggplot(emmeans_soil_yr %>% as_tibble, 
       aes(x = CoverCrop, y = Previous.Crop, fill = response)) +
  geom_tile() +
  facet_wrap(~ Year, nrow = 2) +
  #geom_text(aes(label = trimws(.group))) +
  scale_fill_gradientn(colours = orange_cols, name = 'Soil CFU', labels = comma) +
  hmlabs +
  scale_x_discrete(labels = levels_c) +
  scale_y_discrete(labels = levels_p) +
  ggtitle('Soil disease load') +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.6)), legend.title = element_text(size = rel(0.8)))

hm_yield_yr <- ggplot(emmeans_yield_yr %>% as_tibble, 
       aes(x = CoverCrop, y = Previous.Crop, fill = emmean)) +
  geom_tile() +
  facet_wrap(~ Year, nrow = 2) +
  #geom_text(aes(label = trimws(.group))) +
  scale_fill_gradientn(colours = orange_cols, name = parse(text = 'Yield~(kg~ha^-1)'), labels = comma) +
  hmlabs +
  scale_x_discrete(labels = levels_c) +
  scale_y_discrete(labels = levels_p) +
  ggtitle('Yield') +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.6)), legend.title = element_text(size = rel(0.8)))

png('figs/heatmaps_byyear.png', height = 6, width = 10, res = 300, units = 'in')
  grid.arrange(hm_stem_yr, hm_soil_yr, hm_yield_yr, nrow = 1, top = 'Estimated marginal means by treatment combination & year')
dev.off()


# Fig 3 formatted ---------------------------------------------------------

# No title, letters on panels, tissue CFU and soil CFU, save as eps

hm_stem_yr <- ggplot(emmeans_stem_yr %>% as_tibble, 
                     aes(x = CoverCrop, y = Previous.Crop)) +
  geom_tile(aes(fill = response)) +
  facet_wrap(~ Year, nrow = 2) +
  #geom_text(aes(label = trimws(.group))) +
  scale_fill_gradientn(colours = orange_cols, name = 'Tissue CFU', labels = comma, breaks = c(5000, 10000, 15000, 20000)) +
  hmlabs +
  scale_x_discrete(labels = levels_c) +
  scale_y_discrete(labels = levels_p) +
  #ggtitle('Tissue CFU') +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.5)), legend.title = element_text(size = rel(0.8))) +
  geom_text(data = data.frame(CoverCrop = 'fallow', Previous.Crop = 'corn', Year = c(2011, 2015), letter = c('A', 'D')), aes(label = letter), size = 3.5, hjust = 1, vjust = -0.5)

hm_soil_yr <- ggplot(emmeans_soil_yr %>% as_tibble, 
                     aes(x = CoverCrop, y = Previous.Crop)) +
  geom_tile(aes(fill = response)) +
  facet_wrap(~ Year, nrow = 2) +
  #geom_text(aes(label = trimws(.group))) +
  scale_fill_gradientn(colours = orange_cols, name = 'Soil CFU', labels = comma) +
  hmlabs +
  scale_x_discrete(labels = levels_c) +
  scale_y_discrete(labels = levels_p) +
  #ggtitle('Soil CFU') +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.5)), legend.title = element_text(size = rel(0.8))) +
  geom_text(data = data.frame(CoverCrop = 'fallow', Previous.Crop = 'corn', Year = c(2011, 2015), letter = c('B', 'E')), aes(label = letter), size = 3.5, hjust = 1, vjust = -0.5)

hm_yield_yr <- ggplot(emmeans_yield_yr %>% as_tibble, 
                      aes(x = CoverCrop, y = Previous.Crop)) +
  geom_tile(aes(fill = emmean)) +
  facet_wrap(~ Year, nrow = 2) +
  #geom_text(aes(label = trimws(.group))) +
  scale_fill_gradientn(colours = orange_cols, name = parse(text = 'Yield~(kg~ha^-1)'), labels = comma) +
  hmlabs +
  scale_x_discrete(labels = levels_c) +
  scale_y_discrete(labels = levels_p) +
  #ggtitle('Yield') +
  theme(legend.position = 'bottom', legend.key.width = unit(0.75, 'cm'), legend.text = element_text(size = rel(0.5)), legend.title = element_text(size = rel(0.8))) +
  geom_text(data = data.frame(CoverCrop = 'fallow', Previous.Crop = 'corn', Year = c(2011, 2015), letter = c('C', 'F')), aes(label = letter), size = 3.5, hjust = 1, vjust = -0.5)

noyax <- theme(axis.text.y = element_blank(), axis.title.y = element_blank())
smlabs1 <- theme(axis.text.x = element_text(size = rel(.7)), legend.key.width = unit(0.6, 'cm'), axis.text.y = element_text(size = rel(.7)))
smlabs2 <- theme(axis.text.x = element_text(size = rel(.7)), legend.key.width = unit(0.6, 'cm'))
fig3 <- arrangeGrob(hm_stem_yr + smlabs1, hm_soil_yr + noyax + smlabs2, hm_yield_yr + noyax + smlabs2, nrow = 1, widths = c(1.4, 1, 1))

ggsave('figs/fig3.png', fig3, height = 5, width = 7, dpi = 300)
ggsave('figs/fig3.eps', fig3, height = 5, width = 7)

# Figures for c. soybean analysis -----------------------------------------

##### Figures with boxplots but no raw data, one for each variable
p_box_stem_csoy <- CLDplot_lmm(dat = dat %>% filter(Previous.Crop %in% 'c. soybean'),
            cld = cld_stem_csoy,
            x_var = CoverCrop,
            y_var = StemCFUAvg,
            grp_var = factor(Year),
            x_axis_label = 'Cover Crop',
            y_axis_label = 'Stem CFU',
            log_y = TRUE,
            show_points = FALSE,
            show_caption = FALSE,
            mean_color = 'black',
            points_adj = 0.42, bp_adj = 0.25) +
  ggtitle('Stem disease load') +
  scale_x_discrete(name = 'cover crop', labels = levels_c) +
  scale_fill_brewer(name = 'Year', palette = 'Dark2') +
  theme(legend.position = c(0.8, 0.15), legend.direction = 'horizontal', axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank()) +
  guides(fill = guide_legend(ncol = 3))

p_box_soil_csoy <- CLDplot_lmm(dat = dat %>% filter(Previous.Crop %in% 'c. soybean'),
            cld = cld_soil_csoy,
            x_var = CoverCrop,
            y_var = SoilCFUAvg,
            grp_var = factor(Year),
            x_axis_label = 'Cover Crop',
            y_axis_label = 'Soil CFU',
            log_y = TRUE,
            show_points = FALSE,
            show_caption = FALSE,
            mean_color = 'black',
            points_adj = 0.42, bp_adj = 0.25) +
  ggtitle('Soil disease load') +
  scale_x_discrete(name = 'cover crop', labels = levels_c) +
  scale_fill_brewer(name = 'Year', palette = 'Dark2') +
  scale_color_brewer(name = 'Year', palette = 'Dark2') +
  theme(legend.position = 'none', axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())

p_box_yield_csoy <- CLDplot_lmm(dat = dat %>% filter(Previous.Crop %in% 'c. soybean'),
            cld = cld_yield_csoy,
            x_var = CoverCrop,
            y_var = YldKgHa,
            grp_var = factor(Year),
            x_axis_label = 'Cover Crop',
            y_axis_label = parse(text = 'Yield~(kg~ha^-1)'),
            log_y = FALSE,
            show_points = FALSE,
            show_caption = FALSE,
            mean_color = 'black',
            points_adj = 0.42, bp_adj = 0.25) +
  ggtitle('Yield') +
  scale_x_discrete(name = 'cover crop', labels = levels_c) +
  scale_fill_brewer(name = 'Year', palette = 'Dark2') +
  scale_color_brewer(name = 'Year', palette = 'Dark2') +
  theme(legend.position = 'none')

png('figs/continuoussoy_maineffect_norawdata.png', height = 10, width = 8, res = 300, units = 'in')
  grid.arrange(gtable_rbind(ggplotGrob(p_box_stem_csoy), ggplotGrob(p_box_soil_csoy), ggplotGrob(p_box_yield_csoy)), top = 'Estimated marginal means and data distributions, continuous soybean plots only, 2011-2015')
dev.off()

##### Figures with means and CIs only
# Stem CFU
p_stem_csoy <- ggplot(cld_stem_csoy, aes(x = CoverCrop, y = response, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_c,
                   name = 'cover crop') +
  scale_y_continuous(name = 'Stem CFU',
                     limits = c(0, max(cld_stem_csoy$upper.CL) + 1),
                     expand = expansion(mult = c(0, 0.02))) +
  theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())

p_soil_csoy <- ggplot(cld_soil_csoy, aes(x = CoverCrop, y = response, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_c,
                   name = 'cover crop') +
  scale_y_continuous(name = 'Soil CFU',
                     limits = c(0, max(cld_soil_csoy$upper.CL) + 1),
                     expand = expansion(mult = c(0, 0.02))) +
  theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())

p_yield_csoy <- ggplot(cld_yield_csoy, aes(x = CoverCrop, y = emmean, ymin = lower.CL, ymax = upper.CL, label = str_trim(.group))) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point(size = 2) +
  geom_text(position = position_nudge(x = 0.1), size = letter_size, hjust = 0) +
  scale_x_discrete(labels = levels_c,
                   name = 'cover crop') +
  scale_y_continuous(name = parse(text = 'Yield~(kg~ha^-1)'),
                     limits = c(0, max(cld_yield_csoy$upper.CL) + 1),
                     expand = expansion(mult = c(0, 0.02)))

png('figs/continuoussoy_justmeans.png', height = 10, width = 8, res = 300, units = 'in')
  grid.arrange(gtable_rbind(ggplotGrob(p_stem_csoy), ggplotGrob(p_soil_csoy), ggplotGrob(p_yield_csoy)), top = 'Estimated marginal means, continuous soybean plots only, 2011-2015')
dev.off()

# Figures showing raw data trends through time
ptrend1 <- ggplot(dat %>% filter(Previous.Crop %in% 'c. soybean'), aes(x = Year, y = StemCFUAvg, color = CoverCrop, group = CoverCrop)) +
  geom_point(alpha = 0.5) +
  stat_summary(fun = mean, geom = 'line') +
  stat_summary(fun = mean, geom = 'point', size = 2, shape = 2, stroke = 1.5) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  labs(y = 'Stem CFU') +
  theme(legend.position = c(0.7, 0.8), axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank()) +
  guides(color = guide_legend(ncol = 2))

ptrend2 <- ggplot(dat %>% filter(Previous.Crop %in% 'c. soybean'), aes(x = Year, y = SoilCFUAvg, color = CoverCrop, group = CoverCrop)) +
  geom_point(alpha = 0.5) +
  stat_summary(fun = mean, geom = 'line') +
  stat_summary(fun = mean, geom = 'point', size = 2, shape = 2, stroke = 1.5) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  labs(y = 'Soil CFU') +
  theme(legend.position = 'none', axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())

ptrend3 <- ggplot(dat %>% filter(Previous.Crop %in% 'c. soybean'), aes(x = Year, y = YldKgHa, color = CoverCrop, group = CoverCrop)) +
  geom_point(alpha = 0.5) +
  stat_summary(fun = mean, geom = 'line') +
  stat_summary(fun = mean, geom = 'point', size = 2, shape = 2, stroke = 1.5) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  labs(y = parse(text = 'Yield~(kg~ha^-1)')) +
  theme(legend.position = 'none')

png('figs/continuoussoy_timetrends.png', height = 10, width = 8, res = 300, units = 'in')
  grid.arrange(gtable_rbind(ggplotGrob(ptrend1), ggplotGrob(ptrend2), ggplotGrob(ptrend3)), top = 'Response variable trends over time, continuous soybean plots only, 2011-2015')
dev.off()


# Time trends showing year differences ------------------------------------

ggplot(cld_stem_csoy_byyear, aes(x = Year, y = response, ymin = lower.CL, ymax = upper.CL)) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point() +
  geom_line() +
  geom_text(aes(y = upper.CL + 1000, label = trimws(.group)))

ggplot(cld_soil_csoy_byyear, aes(x = Year, y = response, ymin = lower.CL, ymax = upper.CL)) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point() +
  geom_line() +
  geom_text(aes(y = upper.CL + 10, label = trimws(.group)))

ggplot(cld_yield_csoy_byyear, aes(x = Year, y = emmean, ymin = lower.CL, ymax = upper.CL)) +
  geom_errorbar(width = 0.2, size = line_thickness) +
  geom_point() +
  geom_line() +
  geom_text(aes(y = upper.CL + 100, label = trimws(.group)))


# Plots combine year trends with treatment marginal means -----------------

# Marginal year x treatment means, and marginal year means
# Letters represent differences in years only. No significant treatment effects or interaction between treatment and year for any of the responses.

ptrendmeans1 <- ggplot(cld_stem_csoy_byyear, aes(x = Year, y = response)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  geom_errorbar(width = 0.1, size = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(alpha = 0.5, aes(x = as.numeric(Year))) +
  geom_point(data = as_tibble(emmeans_stem_csoy_yearxtrt), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.1)) +
  geom_text(aes(y = upper.CL + 2000, label = trimws(.group))) +
  labs(y = 'Stem CFU') +
  theme(legend.position = c(0.75, 0.75), axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank()) +
  guides(color = guide_legend(ncol = 2)) 

ptrendmeans2 <- ggplot(cld_soil_csoy_byyear, aes(x = Year, y = response)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  geom_errorbar(width = 0.1, size = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(alpha = 0.5, aes(x = as.numeric(Year))) +
  geom_point(data = as_tibble(emmeans_soil_csoy_yearxtrt), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.1)) +
  geom_text(aes(y = upper.CL + 20, label = trimws(.group))) +
  labs(y = 'Soil CFU') +
  theme(legend.position = 'none', axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())

ptrendmeans3 <- ggplot(cld_yield_csoy_byyear, aes(x = Year, y = emmean)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  geom_errorbar(width = 0.1, size = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(alpha = 0.5, aes(x = as.numeric(Year))) +
  geom_point(data = as_tibble(emmeans_yield_csoy_yearxtrt), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.1)) +
  geom_text(aes(y = upper.CL + 100, label = trimws(.group))) +
  labs(y = parse(text = 'Yield~(kg~ha^-1)')) +
  theme(legend.position = 'none')

png('figs/continuoussoy_timetrends_yearmeans.png', height = 8, width = 6, res = 300, units = 'in')
grid.arrange(gtable_rbind(ggplotGrob(ptrendmeans1), ggplotGrob(ptrendmeans2), ggplotGrob(ptrendmeans3)), top = 'Response variable trends over time, continuous soybean plots only, 2011-2015')
dev.off()


# Fig 5 formatted ---------------------------------------------------------

# No title, tissue CFU instead of stem CFU, letters on panels, save as eps

ptrendmeans1 <- ggplot(cld_stem_csoy_byyear, aes(x = Year, y = response)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  geom_errorbar(width = 0.1, size = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(aes(x = as.numeric(Year))) +
  geom_point(data = as_tibble(emmeans_stem_csoy_yearxtrt), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.15)) +
  geom_text(aes(y = upper.CL + 2000, label = trimws(.group))) +
  labs(y = 'Tissue CFU') +
  theme(legend.position = c(0.7, 0.75), axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank(), 
        legend.background = element_blank(), legend.text = element_text(size = rel(0.6)), legend.title = element_text(size = rel(0.72))) +
  guides(color = guide_legend(ncol = 2)) 

ptrendmeans2 <- ggplot(cld_soil_csoy_byyear, aes(x = Year, y = response)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  geom_errorbar(width = 0.1, size = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(aes(x = as.numeric(Year))) +
  geom_point(data = as_tibble(emmeans_soil_csoy_yearxtrt), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.15)) +
  geom_text(aes(y = upper.CL + 20, label = trimws(.group))) +
  labs(y = 'Soil CFU') +
  theme(legend.position = 'none', axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank())

ptrendmeans3 <- ggplot(cld_yield_csoy_byyear, aes(x = Year, y = emmean)) +
  scale_color_brewer(palette = 'Dark2', name = 'cover crop', labels = levels_c) +
  geom_errorbar(width = 0.1, size = line_thickness, aes(ymin = lower.CL, ymax = upper.CL)) +
  geom_point(size = 2) +
  geom_line(aes(x = as.numeric(Year))) +
  geom_point(data = as_tibble(emmeans_yield_csoy_yearxtrt), aes(color = CoverCrop), shape = 1, size = 2, position = position_nudge(x = -0.15)) +
  geom_text(aes(y = upper.CL + 120, label = trimws(.group))) +
  labs(y = parse(text = 'Yield~(kg~ha^-1)')) +
  theme(legend.position = 'none')

fig5 <- arrangeGrob(gtable_rbind(ggplotGrob(ptrendmeans1 + letter_annotate('A')), 
                                 ggplotGrob(ptrendmeans2 + letter_annotate('B')), 
                                 ggplotGrob(ptrendmeans3 + letter_annotate('C'))))

ggsave('figs/fig5.png', fig5, height = 6, width = 3.25, dpi = 400)
ggsave('figs/fig5.eps', fig5, height = 6, width = 3.25)

# Pairs plot (fig 4) ------------------------------------------------------

library(GGally)

lab_exp <- c(logSoilCFU = 'log[10]~Soil~CFU', logStemCFU = 'log[10]~Stem~CFU', YldKgHa = 'Yield~(kg~ha^-1)')

fig4 <- dat %>%
  mutate(logSoilCFU = log10(SoilCFUAvg), logStemCFU = log10(StemCFUAvg)) %>%
  dplyr::select(logSoilCFU, logStemCFU, YldKgHa) %>%
  setNames(lab_exp) %>%
  ggpairs(labeller = label_parsed, switch = 'y', showStrips = FALSE) + theme(strip.placement = "outside")

ggsave('figs/fig4.png', fig4, height = 6, width = 7, dpi = 400)
ggsave('figs/fig4.eps', fig4, height = 6, width = 7)
