# Strip plot code
library(tidyverse)
library(readxl)
library(lme4)
library(emmeans)
library(multcomp)
library(multcompView)
library(agricolae)

levels_pcrop <- c('c. soybean', 'soybean', 'cotton', 'corn')
levels_ccrop <- c('fallow', 'poultry litter', 'wheat', 'austrian winter pea', 'hairy vetch')

dat <- read_xlsx('Quentin combined data with Yld 2011-2015.xlsx', sheet = 1, .name_repair = 'universal', na = c('', ' ', '.')) %>%
  mutate(Previous.Crop = factor(tolower(Previous.Crop), levels = levels_pcrop),
         CoverCrop = factor(tolower(CoverCrop), levels = levels_ccrop))

with(dat %>% filter(Year == 2015), strip.plot(Rep, Previous.Crop, CoverCrop, log10(StemCFUAvg)))
with(dat %>% filter(Year == 2015), strip.plot(Rep, Previous.Crop, CoverCrop, log10(SoilCFUAvg)))
with(dat %>% filter(Year == 2015), strip.plot(Rep, Previous.Crop, CoverCrop, log10(YldKgHa)))
with(dat %>% filter(Year == 2015), strip.plot(Rep, Previous.Crop, CoverCrop, YldKgHa))
with(dat %>% filter(Year == 2011), strip.plot(Rep, Previous.Crop, CoverCrop, log10(StemCFUAvg)))
with(dat %>% filter(Year == 2011), strip.plot(Rep, Previous.Crop, CoverCrop, log10(SoilCFUAvg)))
with(dat %>% filter(Year == 2011), strip.plot(Rep, Previous.Crop, CoverCrop, log10(YldKgHa)))
with(dat %>% filter(Year == 2011), strip.plot(Rep, Previous.Crop, CoverCrop, YldKgHa))

with(dat %>% filter(Year == 2011), strip.plot(Rep, Previous.Crop, CoverCrop, log10(StemCFUAvg)))
anova(lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + (1|Rep) + (1|Previous.Crop:Rep) + (1|CoverCrop:Rep), data = dat, subset = Year == 2011))
anova(lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + (1|Rep) + (1|Previous.Crop:Rep) + (1|CoverCrop:Rep), data = dat, subset = Year == 2015))
anova(lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + (1|Rep) + (1|Previous.Crop:Rep) + (1|CoverCrop:Rep) + (1|Year), data = dat, subset = Year %in% c(2011, 2015)))
anova(lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + (1|Previous.Crop:Rep) + (1|CoverCrop:Rep) + (1|Year), data = dat, subset = Year %in% c(2011, 2015)))

# Suggestion is to treat year as a fixed effect, as there are only two. 
# See https://stat.ethz.ch/pipermail/r-sig-mixed-models/2019q3/028145.html

anova(lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + Year + (1|Previous.Crop:Rep) + (1|CoverCrop:Rep), data = dat, subset = Year %in% c(2011, 2015)))

fit_stem <- lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + Year + (1|Rep/Previous.Crop/CoverCrop), data = dat, subset = Year %in% c(2011, 2015))
fit_soil <- lmer(log10(SoilCFUAvg) ~ Previous.Crop * CoverCrop + Year + (1|Rep/Previous.Crop/CoverCrop), data = dat, subset = Year %in% c(2011, 2015))
fit_yield <- lmer(YldKgHa ~ Previous.Crop * CoverCrop + Year + (1|Rep/Previous.Crop/CoverCrop), data = dat, subset = Year %in% c(2011, 2015))
# 
# # One year only
# anova(lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + (1|Rep/Previous.Crop/CoverCrop), data = dat, subset = Year %in% c(2011)))
# anova(lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + (1|Rep/Previous.Crop/CoverCrop), data = dat, subset = Year %in% c(2015)))

emmeans_stem <- emmeans(fit_stem, specs = c('Previous.Crop', 'CoverCrop'), mode = 'kenward-roger', type = 'response')
emmeans_soil <- emmeans(fit_soil, specs = c('Previous.Crop', 'CoverCrop'), mode = 'kenward-roger', type = 'response')
emmeans_yield <- emmeans(fit_yield, specs = c('Previous.Crop', 'CoverCrop'), mode = 'kenward-roger', type = 'response')
cld(emmeans_stem, adjust = 'tukey', Letters = letters)
cld(emmeans_soil, adjust = 'tukey', Letters = letters)
cld(emmeans_yield, adjust = 'tukey', Letters = letters)

emmeans_stem_p <- emmeans(fit_stem, specs = c('Previous.Crop'), mode = 'kenward-roger', type = 'response')
pairs(emmeans_stem_p)
pairs(regrid(emmeans_stem_p), infer = TRUE)

### Quick attempt to convert this to a Bayesian model with rstanarm
library(rstanarm)
stanfit1_stem <- stan_lmer(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + Year + (1|Rep/Previous.Crop/CoverCrop), data = dat, subset = Year %in% c(2011, 2015))
