# Map of relative plot locations to be used for spatial autocorrelation error in model

library(readxl)
library(abind)
#library(spaMM)
library(nlme)

map_xl <- read_xls('C:/Users/Quentin/OneDrive - USDA/ars_projects/mengistu/Cropping Systems map 2010-2017 for Jeff.xls', sheet = 1, skip = 4, col_names = FALSE, n_max = 15)

map_xl <- map_xl[,-1]

# Get coordinates of each cell
map_array <- abind(map_xl, row(map_xl), col(map_xl), along = 0)
plot_coords <- do.call(rbind, apply(map_array, 3, t, simplify = FALSE))
plot_coords <- setNames(as.data.frame(plot_coords), c('Plot', 'y', 'x'))
plot_coords <- plot_coords[!is.na(plot_coords$Plot), ]

# Add coordinates to dat and try to fit spatial model
dat <- left_join(dat, plot_coords)
#dat <- mutate(dat, Year = factor(Year))

# fitspam_stem <- fitme(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + Year + Matern(1 | y + x), data = dat %>% filter(Year %in% c(2011,2015)), family = 'gaussian')
# fitspam_stem_null <- fitme(log10(StemCFUAvg) ~ Year + Matern(1 | y + x), data = dat %>% filter(Year %in% c(2011,2015)), family = 'gaussian')
# anova(fitspam_stem, fitspam_stem_null)
# 
# fitspam_stem <- fitme(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + Year + Matern(1 | y + x), data = dat %>% filter(Year %in% c(2011,2015)))
# fitspam_stem_null <- fitme(log10(StemCFUAvg) ~ Year + Matern(1 | y + x), data = dat %>% filter(Year %in% c(2011,2015)))
# anova(fitspam_stem, fitspam_stem_null)

# Also just try nlme with corExp()
# exp_cor <- corExp(~ x + y)
# nlme::Initialize(exp_cor, dat)

# GLS: Fixed effects only, with spatially correlated errors
fitgls_stem <- gls(log10(StemCFUAvg) ~ Previous.Crop * CoverCrop + Year,
                   correlation = corExp(form = ~ x + y | Year),
                   data = dat %>% mutate(Year = factor(Year)),
                   subset = Year %in% c(2011, 2015) & !is.na(StemCFUAvg))

anova(fitgls_stem)

emmeans_pcrop_glsstem <- emmeans(fitgls_stem, specs = 'Previous.Crop', mode = 'appx-satterthwaite', type = 'response')
emmeans_ccrop_glsstem <- emmeans(fitgls_stem, specs = 'CoverCrop', mode = 'appx-satterthwaite', type = 'response')
emmeans_both_glsstem <- emmeans(fitgls_stem, specs = c('Previous.Crop', 'CoverCrop'), mode = 'appx-satterthwaite', type = 'response')
cld_pcrop_glsstem <- cld(emmeans_pcrop_glsstem, adjust = 'Tukey', Letters = letters)
cld_ccrop_glsstem <- cld(emmeans_ccrop_glsstem, adjust = 'Tukey', Letters = letters)
cld_both_glsstem <- cld(emmeans_both_glsstem, adjust = 'Tukey', Letters = letters)


fitgls_soil <- gls(log10(SoilCFUAvg) ~ Previous.Crop * CoverCrop + Year,
                   correlation = corExp(form = ~ x + y | Year),
                   data = dat %>% mutate(Year = factor(Year)),
                   subset = Year %in% c(2011, 2015) & !is.na(SoilCFUAvg))

anova(fitgls_soil)

emmeans_pcrop_glssoil <- emmeans(fitgls_soil, specs = 'Previous.Crop', mode = 'appx-satterthwaite', type = 'response')
emmeans_ccrop_glssoil <- emmeans(fitgls_soil, specs = 'CoverCrop', mode = 'appx-satterthwaite', type = 'response')
emmeans_both_glssoil <- emmeans(fitgls_soil, specs = c('Previous.Crop', 'CoverCrop'), mode = 'appx-satterthwaite', type = 'response')
cld_pcrop_glssoil <- cld(emmeans_pcrop_glssoil, adjust = 'Tukey', Letters = letters)
cld_ccrop_glssoil <- cld(emmeans_ccrop_glssoil, adjust = 'Tukey', Letters = letters)
cld_both_glssoil <- cld(emmeans_both_glssoil, adjust = 'Tukey', Letters = letters)

fitgls_yield <- gls(YldKgHa ~ Previous.Crop * CoverCrop + Year,
                   correlation = corExp(form = ~ x + y | Year),
                   data = dat %>% mutate(Year = factor(Year)),
                   subset = Year %in% c(2011, 2015) & !is.na(YldKgHa))

anova(fitgls_yield)

emmeans_pcrop_glsyield <- emmeans(fitgls_yield, specs = 'Previous.Crop', mode = 'appx-satterthwaite', type = 'response')
emmeans_ccrop_glsyield <- emmeans(fitgls_yield, specs = 'CoverCrop', mode = 'appx-satterthwaite', type = 'response')
emmeans_both_glsyield <- emmeans(fitgls_yield, specs = c('Previous.Crop', 'CoverCrop'), mode = 'appx-satterthwaite', type = 'response')
cld_pcrop_glsyield <- cld(emmeans_pcrop_glsyield, adjust = 'Tukey', Letters = letters)
cld_ccrop_glsyield <- cld(emmeans_ccrop_glsyield, adjust = 'Tukey', Letters = letters)
cld_both_glsyield <- cld(emmeans_both_glsyield, adjust = 'Tukey', Letters = letters)

# Continuous soy, with year as random effect
fit_stem_csoy <- lme(log10(StemCFUAvg) ~ CoverCrop,
                     random = ~ 1 | Year, 
                     correlation = corExp(form = ~ x + y | Year),
                     data = dat, subset = Previous.Crop %in% 'c. soybean' & !is.na(StemCFUAvg))

anova(fit_stem_csoy)
emmeans_stem_csoy <- emmeans(fit_stem_csoy, specs = 'CoverCrop', mode = 'satterthwaite', type = 'response')
cld_stem_csoy <- cld(emmeans_stem_csoy, adjust = 'Tukey', Letters = letters)

fit_soil_csoy <- lme(log10(SoilCFUAvg) ~ CoverCrop,
                     random = ~ 1 | Year, 
                     correlation = corExp(form = ~ x + y | Year),
                     data = dat, subset = Previous.Crop %in% 'c. soybean' & !is.na(SoilCFUAvg))

anova(fit_soil_csoy)
emmeans_soil_csoy <- emmeans(fit_soil_csoy, specs = 'CoverCrop', mode = 'containment', type = 'response') # Satterthwaite algo fails
cld_soil_csoy <- cld(emmeans_soil_csoy, adjust = 'Tukey', Letters = letters)

fit_yield_csoy <- lme(YldKgHa ~ CoverCrop,
                     random = ~ 1 | Year, 
                     correlation = corExp(form = ~ x + y | Year),
                     data = dat, subset = Previous.Crop %in% 'c. soybean' & !is.na(YldKgHa))

anova(fit_yield_csoy)
emmeans_yield_csoy <- emmeans(fit_yield_csoy, specs = 'CoverCrop', mode = 'satterthwaite', type = 'response')
cld_yield_csoy <- cld(emmeans_yield_csoy, adjust = 'Tukey', Letters = letters)
